Rename almost all occurences of LinuxBIOS to coreboot. 
Due to the automatic nature of this update, I am self-acking. It worked in
abuild.

Signed-off-by: Stefan Reinauer <stepan@coresystems.de>
Acked-by: Stefan Reinauer <stepan@coresystems.de>



git-svn-id: svn://svn.coreboot.org/coreboot/trunk@3053 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
diff --git a/src/boot/hardwaremain.c b/src/boot/hardwaremain.c
index eb97124..cc3741f 100644
--- a/src/boot/hardwaremain.c
+++ b/src/boot/hardwaremain.c
@@ -22,7 +22,7 @@
 
 
 /*
- * C Bootstrap code for the LinuxBIOS
+ * C Bootstrap code for the coreboot
  */
 
 
@@ -38,9 +38,9 @@
 #include <boot/elf.h>
 
 /**
  * @brief Main function of the DRAM part of LinuxBIOS.
  *
  * LinuxBIOS is divided into Pre-DRAM part and DRAM part. 
  *
  * 
  * Device Enumeration:
@@ -57,8 +57,8 @@
 	
 	post_code(0x39);
 
-	printk_notice("LinuxBIOS-%s%s %s %s...\n", 
-		      linuxbios_version, linuxbios_extra_version, linuxbios_build,
+	printk_notice("coreboot-%s%s %s %s...\n", 
+		      coreboot_version, coreboot_extra_version, coreboot_build,
 		      (boot_complete)?"rebooting":"booting");
 
 	post_code(0x40);
@@ -38,9 +38,9 @@
 
 /**
- * @brief Main function of the DRAM part of LinuxBIOS.
+ * @brief Main function of the DRAM part of coreboot.
  *
@@ -38,9 +38,9 @@
  *
- * LinuxBIOS is divided into Pre-DRAM part and DRAM part. 
+ * Coreboot is divided into Pre-DRAM part and DRAM part. 
  *
  * 